SceneObject class

Constructors

SceneObject({Vector3? position, Vector3? rotation, Vector3? scale, String? name, Mesh? mesh, Scene? scene, SceneObject? parent, List<SceneObject>? children, bool backfaceCulling = true, bool lighting = false, bool visiable = true, bool normalized = true, String? fileName, bool isAsset = true})

Properties

backfaceCulling bool
The backface will be culled without rendering.
getter/setter pair
children List<SceneObject>
The children of this object.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lighting bool
Enable basic lighting, default to false.
getter/setter pair
mesh Mesh
The mesh of this object
getter/setter pair
name String?
The name of this object.
getter/setter pair
parent SceneObject?
The parent of this object.
getter/setter pair
position → Vector3
The local position of this object relative to the parent. Default is Vector3(0.0, 0.0, 0.0). updateTransform after you change the value.
final
rotation → Vector3
The local rotation of this object relative to the parent. Default is Vector3(0.0, 0.0, 0.0). updateTransform after you change the value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale → Vector3
The local scale of this object relative to the parent. Default is Vector3(1.0, 1.0, 1.0). updateTransform after you change the value.
final
scene Scene?
getter/setter pair
transform Matrix4
The transformation of the object in the scene, including position, rotation, and scaling.
final
visiable bool
Is this object visiable.
getter/setter pair

Methods

add(SceneObject object) → void
Add a child
find(Pattern name) SceneObject?
Find a child matching the name
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(SceneObject object) → void
Remove a child
toString() String
A string representation of this object.
inherited
updateTransform() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited